@@ -9,7 +9,7 @@ use warnings;
 use Carp;
 use JSON::RPC::Legacy::Client;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 my @CONFIG_VARS = qw(apikey password url username);
 
@@ -38,7 +38,7 @@ sub DESTROY {
     if ($self->is_logged_in()) {
         $self->logout();
     }
-    return undef;
+    return;
 } # DESTROY()
 
 sub request {
@@ -86,7 +86,7 @@ sub request {
         };
         return $res;
     }
-    return undef;
+    return;
 } # request()
 
 sub login {
@@ -109,7 +109,7 @@ sub login {
         $self->{session_id} = $res->{content}->{result}->{'session-id'};
         return $res;
     }
-    return undef;
+    return;
 } # login()
 
 sub logout {
@@ -175,6 +175,9 @@ sub _read_config_fh {
     }
 
     $config->{apikey} = $config->{key} unless ( exists $config->{apikey} );
+    unless ( $config->{url} =~ m|/src/jsonrpc[.]php$| ) {
+        $config->{url} =~ s#/?$#/src/jsonrpc.php#;
+    }
 
     return $config;
 } # _read_config_fh()
@@ -197,7 +200,7 @@ WebService::IdoitAPI - a library to access the i-doit JSON RPC API
 
 =head1 VERSION
 
-Version v0.2.0
+Version v0.2.1
 
 =head1 SYNOPSIS
 
@@ -368,10 +371,6 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=WebService-IdoitAPI>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/WebService-IdoitAPI>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/WebService-IdoitAPI>
